%define _ssldir %(openssl-config --openssldir)

Name: dovecot
Version: 1.0
Release: alt11.alt0.M24.1

Summary: Dovecot secure IMAP/POP3 server
License: GPL
Group: System/Servers
Url: http://%name.org/

Packager: Sergey Ivanov <seriv@altlinux.ru>

PreReq: shadow-utils, service, openssl >= 0.9.6g-alt2

###########################################
# Relations with other POP3/IMAP server pkgs (like courier-imap)

# Provide the abstract service names (which are virtual pkg names),
# specify their origin (our pkg name as the epoch + version-release):
Provides: IMAPD = %name:%version-%release
Provides: POP3D = %name:%version-%release

# End of the statements to describe relations with other POP3/IMAP server pkgs
########################################

Source0: %name-1.0.tar.gz
Source1: %name.init
Source2: %name.pam
Source4: %name-wiki.tar.gz

# ALT patches
Patch0: %name-1.0.rc29-alt-mkcert.patch
Patch1: %name-1.0-rc24-alt-conf.patch

BuildPreReq: automake_1.8
# Automatically added by buildreq on Sun Apr 08 2007
BuildRequires: gcc-c++ glib2 libMySQL-devel libldap-devel libpam-devel libpq3-devel libsasl2-devel libssl-devel libstdc++-devel openssl pkgconfig postgresql-devel zlib-devel


%description
Dovecot is an IMAP/POP3 server for Linux/UNIX-like systems, written with
security primarily in mind. Although it's written with C, it uses
several coding techniques to avoid most of the common pitfalls.

Dovecot can work with standard mbox and maildir formats and it's fully
compatible with UW-IMAP and Courier IMAP servers as well as mail
clients accessing the mailboxes directly.

%package -n dovecot-devel
Summary: Libraries and headers for Dovecot
Group: Development/Other

%package -n dovecot-doc
Summary: local copy of dovecot-wiki, created from http://wiki.dovecot.org/
Group: System/Servers

%description -n dovecot-devel
Headers and static libraries for Dovecot

%description -n dovecot-doc
local copy of dovecot-wiki, created from http://wiki.dovecot.org/


%prep
%setup -n %name-1.0 -q
%patch0 -p1
%patch1 -p1
%setup -n %name-1.0 -T -D -a 4
mv dovecot-wiki/*txt doc/wiki/
rm -f dovecot-wiki/error.log
rmdir dovecot-wiki
cd doc/wiki
cp -f Makefile.am.in Makefile.am
echo *.txt | sed 's/ / \\\n     /g' >> Makefile.am


%build
%set_automake_version 1.8

export CPPFLAGS="`pkg-config --cflags-only-I openssl`"
export LDFLAGS="`pkg-config --libs-only-L openssl`"

%__aclocal
%__autoheader
%__libtoolize --force
%__automake --add-missing
%__autoconf

%configure \
	    --localstatedir=%_var                   \
	    --libexecdir=%_libdir                   \
	    --with-moduledir=%_libdir/%name/modules \
	    --sysconfdir=%_sysconfdir/%name         \
	    --enable-ipv6                           \
	    --enable-header-install                 \
	    --with-rawlog                           \
	    --with-ssl=openssl                      \
	    --with-pop3d                            \
	    --with-pgsql                            \
	    --with-mysql                            \
	    --with-sqlite                           \
	    --with-ldap                             \
	    --with-cyrus-sasl2
%make_build

%install
%make_install DESTDIR=%buildroot install

## Cleanup

# We will make our own %%doc set
%__rm -rf %buildroot%_docdir/%name

## Install

%__mkdir_p -m 0755 %buildroot%_sysconfdir/pam.d
%__mkdir_p -m 0755 %buildroot%_initdir
%__mkdir_p -m 0755 %buildroot%_sysconfdir/%name
%__mkdir_p -m 0755 %buildroot%_datadir/%name
%__mkdir_p -m 0755 %buildroot%_ssldir/{certs,private}

# Base directory
%__mkdir_p -m 0700 %buildroot%_var/run/%name

# Chroot for imap-login
%__mkdir_p -m 0750 %buildroot%_var/run/%name/login

# Init script
%__install -m 0755 %SOURCE1 %buildroot%_initdir/%name

# PAM config
%__install -m 0600 %SOURCE2 %buildroot%_sysconfdir/pam.d/%name

# Default config
%__mv -f %buildroot%_sysconfdir/%name/%name{-example,}.conf

# OpenSSL stuff
# Need more working on it.
%__mv doc/dovecot-openssl.cnf %buildroot%_sysconfdir/%name
%__install -m 0755 doc/mkcert.sh %buildroot%_datadir/%name/mkcert

# Ghosts. How to include it in package and remove on
# package remove without checking of size mismatch?
touch %buildroot%_ssldir/certs/%name.pem
touch %buildroot%_ssldir/private/%name.pem
touch %buildroot%_var/run/%name/ssl-parameters.dat

# devel files
%__mkdir -p %buildroot%{_includedir}/%{name}/{deliver,lib,lib-mail,lib-storage}
%__mkdir -p %buildroot%{_libdir}/%{name}/modules/{lib,lib-mail,lib-storage}

%__install -p -m644 dovecot-config %buildroot%{_includedir}/%{name}
for folder in deliver lib lib-mail lib-storage
do
    if [ -d $RPM_BUILD_ROOT%{_libdir}/%{name}/modules/$folder/ ]; then
        %__install -p -m644 src/$folder/*.a %buildroot%{_libdir}/%{name}/modules/$folder/
    fi
done

# Done


%pre
%_sbindir/groupadd -r -f %name 2>/dev/null ||:
%_sbindir/useradd -r -n -g %name -d %_var/run/%name \
 -s /dev/null -c 'Dovecot secure IMAP server' %name 2>/dev/null ||:

%post
%post_service %name


%preun
%preun_service %name
#%postun
#if id %name >/dev/null 2>&1; then
# 	userdel %name
#fi

#if sg %name -c true >/dev/null 2>&1; then
#	groupdel nntpcache
#fi

%files
%config(noreplace) %_sysconfdir/%name/%name.conf
%config(noreplace) %_sysconfdir/%name/dovecot-openssl.cnf
%config(noreplace) %_sysconfdir/pam.d/%name
%config(noreplace) %_initdir/%name

%dir %attr(0700,root,root) %_var/run/%name
%dir %attr(0750,root,%name) %_var/run/%name/login
%dir %_libdir/%name

%_libdir/%name/checkpassword-reply
%_libdir/%name/deliver
%_libdir/%name/dict
%_libdir/%name/dovecot-auth
%_libdir/%name/gdbhelper
%_libdir/%name/imap
%_libdir/%name/imap-login
%_libdir/%name/pop3
%_libdir/%name/pop3-login
%_libdir/%name/rawlog
%_libdir/%name/ssl-build-param
%_libdir/%name/idxview
%_libdir/%name/logview
%_libdir/%name/modules/*.so
%_libdir/%name/modules/imap/*.so
%_libdir/%name/modules/pop3/*.so
%_libdir/%name/modules/lda/*.so

%_sysconfdir/%name
%_datadir/%name
%_sbindir/*

%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %_var/run/%name/ssl-parameters.dat
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %_ssldir/certs/%name.pem
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %_ssldir/private/%name.pem

%doc doc/*.txt INSTALL AUTHORS ChangeLog
%doc COPYING* TODO README NEWS doc/*.conf

%files -n dovecot-devel
%{_libdir}/%{name}/dovecot-config
%{_libdir}/%{name}/modules/*.a
%{_libdir}/%{name}/modules/*.la
%{_libdir}/%{name}/modules/imap/*.a
%{_libdir}/%{name}/modules/imap/*.la
%{_libdir}/%{name}/modules/lib/*.a
%{_libdir}/%{name}/modules/lib-mail/*.a
%{_libdir}/%{name}/modules/lib-storage/*.a
%{_includedir}/%{name}

%files -n dovecot-doc
%doc doc/wiki/*.txt

%changelog
* Mon Apr 16 2007  Sergey Ivanov <seriv@altlinux.org> 1.0-alt11.alt0.M24.1
- Backporting to Master 2.4

* Sun Apr 14 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt11
- fix errors in -alt10 release of dovecot: by my mistake there were not applied recent patches.

* Thu Apr 13 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt10
- release 1.0.rc32 renamed to be 1.0; updated wiki to current state

* Thu Apr 12 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt9.rc32
- updated to rc32

* Sun Apr 08 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt9.rc31
- updated to rc31

* Fri Apr 06 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt9.rc30
- updated to rc30

* Fri Mar 30 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt9.rc29
- added doc/wiki/*txt files to dovecot-doc.rpm

* Fri Mar 30 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc29
- rc29: security fix: If zlib plugin was loaded, it was possible to open
  gzipped mbox files outside the user's mail directory.
  Other fixes and cleanups.

* Thu Mar 29 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc28.cvs20070329
- fix Bug #11255: generate certificates if needed at start, not at install;
  strip unneeded details in output;
  patches from cvs up to 2007-03-29.

* Sun Mar 25 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc28.cvs20070325
- upstream --enable-header-install obsoletes half hacks for dovecot-devel;
  patches from cvs up to 2007-03-25.

* Sat Mar 24 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc28.cvs20070324
- update to rc28 + patches from cvs up to 2007-03-24.

* Wed Mar 21 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc27.cvs20070321
- update to rc27 + patches from cvs up to 2007-03-21.

* Fri Mar 02 2007 Stanislav Ievlev <inger@altlinux.org> 1.0-alt8.rc24.1
- uncomment socket section in default config
- add dovecot-auth control

* Thu Feb 22 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc24
- upgrade to rc24

* Wed Feb 21 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc23
- upgrade to rc23

* Tue Feb 06 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc22
- upgrade to rc22

* Sat Feb 03 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc21
- upgrade to rc21

* Tue Jan 23 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc19
- upgrade to rc19: ACL plugin wasn't working in rc18

* Mon Jan 22 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc18
- upgrade to rc18.

* Sun Jan 07 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc17
- upgrade to rc17: fixed MySQL authentication broken in rc16.

* Sat Jan 06 2007 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc16
- upgrade to rc16; fixed section Files which was broken in alt8.rc15

* Sat Nov 18 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc15
- upgrade to rc15

* Mon Nov 13 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt8.rc14
- Split to dovecot, dovecot-devel, dovecot-sieve removed to a separate 
  package. Refix #9634 (previous fix was lost during upgrades).

* Sun Nov 12 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt7.rc14
- upgrade to rc14

* Fri Nov 10 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt7.rc13
- sieve plugin update to 1.0

* Wed Nov 08 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt6.rc13
- update to rc13

* Sun Nov 05 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt6.rc12
- update to rc12

* Sat Nov 04 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt6.rc11
- update to rc11

* Mon Oct 16 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt6.cvs20061016
- Update to recent dovecot rc10 and dovecot-sieve;
  now dovecot.index.cache files have the same format for 32- and 64-bit machines.

* Fri Oct 13 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt6.cvs20060926
- Restore dovecot's deliver agent building

* Thu Sep 28 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt5.cvs20060926
- Fix #10045 & update to cvs20060926 (rc7+)

* Sun Sep 17 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt5.cvs20060812
- Fix #9915

* Fri Sep 15 2006 ALT QA Team Robot <qa-robot@altlinux.org> 1.0-alt4.cvs20060812.1
- Rebuilt with MySQL-5.0.24-alt2.

* Wed Aug 16 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt4.cvs20060812
- fix bug #9836; update to cvs version of Aug/16/2006 (rc6+)

* Wed Jul 05 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt3.rc2
- updated to rc2

* Mon Jul 03 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt3.rc1
- fix #9634 by defaulting pop3_uidl_format = %%08Xu%%08Xv

* Wed Jun 28 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt2.rc1
- updated to rc1.

* Mon Jun 26 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt2.cvs20060626
- Bug 9719 fixed in upstream, dovecot updated to CVS snapshot

* Fri Jun 23 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt2.cvs20060619
- Reverted to CVS version of 2006.06.19: recent changes with strict UID policy
  don't work on my mailboxes.

* Thu Jun 22 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt1.cvs20060622
- updated to beta9, see Changelog. Sieve delivery agent now renamed to sievec. 
  Also closes bug #9634. 

* Wed Apr 12 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt1.cvs20060412
- updated to beta7, see Changelog; now with working sieve-like delivery

* Fri Mar 03 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt1.cvs20060303
- s/%_libexecdir\/%name/%_libdir\/%name/ in %files section

* Mon Feb 27 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt0.cvs20060227
- updated to beta3 from cvs, with memory leak and other fixes;
  disabled sieve-like local delivery agent for now.

* Wed Feb 15 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt0.cvs20060215
- updated to beta3 from cvs, with security fixes

* Mon Jan 30 2006 Sergey Ivanov <seriv@altlinux.org> 1.0-alt0.cvs20060130
- built from dovecot cvs 2006-01-30 and with sieve local delivery agent

* Sun Dec 04 2005 Sergey Ivanov <seriv@altlinux.ru> 1.0-alt0.cvs20051204
- 1.0-alpha4 of nightly cvs builds at 12/04/2005

* Mon Nov 21 2005 Sergey Ivanov <seriv@altlinux.ru> 0.99.14-alt5
- Fix postgresql-devel dependency, removed version number binding;
  fix %_libexecdir - %_libdir confusion;
  fix documentation installation. 

* Tue Oct 11 2005 Sergey Ivanov <seriv@altlinux.ru> 0.99.14-alt4
- removed undefined macro from commented-out text; 
  removed conflicting relation to other POP3/IMAP servers

* Fri Aug 05 2005 Sergey Ivanov <seriv@altlinux.ru> 0.99.14-alt3
- Fix #7479

* Sun May 22 2005 Sergey Ivanov <seriv@altlinux.ru> 0.99.14-alt2
- Buildreq fix: removed version binding for libpq-devel

* Fri Feb 18 2005 Sergey Ivanov <seriv@altlinux.ru> 0.99.14-alt1
-  Message address fields are now parsed differently, fixing some
  issues with spaces. Affects only clients which use FETCH ENVELOPE
  command.
- Message MIME parser was somewhat broken with missing MIME boundaries
- mbox: Don't allow X-UID headers in mails to override the UIDs we
  would otherwise set. Too large values can break some clients and
  cause other trouble.
- passwd-file userdb wasn't working
- PAM crashed with 64bit systems
- non-SSL inetd startup wasn't working
- If UID FETCH notices and skips an expunged message, don't return
  a NO reply. It's not needed and only makes clients give error
  messages.

* Thu Jan 06 2005 Sergey Ivanov <seriv@altlinux.ru> 0.99.13-alt1
- Update to new version. From it's changelog:
  * GNUTLS support hasn't been working for a while, so it's not even
    tried to be used anymore unless explicitly wanted.
  + Added CRAM-MD5 authentication mechanism. Patch by Joshua Goodall
  + Added SMD5 and LDAP-MD5 password schemes and changed MD5 scheme to
    use LDAP-MD5 if the password isn't in MD5crypt format. Patch by
    Joshua Goodall
  + Workaround for some POP3 client bugs: if message doesn't contain the
    "end of headers" empty line, add it automatically.
  + vpopmail supports now all password schemes, most importantly
    MD5crypt works now without support from libc's crypt()
  - SQL and LDAP authentication was broken
  - SEARCH UNKEYWORD wasn't working

* Sun Dec 05 2004 Sergey Ivanov <seriv@altlinux.ru> 0.99.12-alt1
- Updated to new version. From changelog of 0.99.12:
    - Fix memory leaks in LDAP, MySQL and PGSQL userdb/passdb
    - Fix hanging when parsing mails that have over 4096 bytes in one
      line (SMTP servers normally don't allow over 1000 bytes so it
      shouldn't be much of a problem)
    - FETCH BODYSTRUCTURE sometimes gave a wrong reply
      (eg. with FETCH (BODYSTRUCTURE RFC822.SIZE) if it wasn't cached)
    - Never return more than one INBOX in LIST even if there are such
      files. They don't work anyway and it just confuses clients.
    - mbox: Don't allow creating INBOX directory by creating/renaming
      mailboxes under it. They just wouldn't work.
    - POP3: Don't return PLAIN in SASL list. We don't support initial SASL
      responses, so it only breaks with most clients that try to use it.
    - IMAP and POP3 login processes may have sent each line in two IP
      packets, one with the data and another with CR+LF. Some clients
      didn't work because of this. 

* Thu Sep 23 2004 Sergey Ivanov <seriv@altlinux.ru> 0.99.11-alt1
- Updated to 0.99.11

* Mon Aug 02 2004 Sergey Ivanov <seriv@altlinux.ru> 0.99.10.9-alt1
- Update to 0.99.10.9

* Fri Jul 30 2004 Sergey Ivanov <seriv@altlinux.ru> 0.99.10.8-alt1
- Updated to 0.99.10.8

* Sat Jan 10 2004 Anton V. Denisov <avd@altlinux.org> 0.99.10.4-alt1.1
- Explicitly use automake-1.4 for build and run %%__automake before 
  %%configure (hope this fix build with new autotools and GCC).

* Mon Dec 15 2003 Anton V. Denisov <avd@altlinux.org> 0.99.10.4-alt1
- Updated to 0.99.10.4 (bugfix release).

* Tue Dec 09 2003 Anton V. Denisov <avd@altlinux.org> 0.99.10.2-alt1
- Initial release for ALT Linux Sisyphus.

* Mon Dec 08 2003 Anton V. Denisov <avd@altlinux.org> 0.99.10.2-alt0.2
- Built with pop3 daemon and enable it in config.
- Add into %%summary and %%descrition info about POP3 protocol.
- Minor improvements in %%files section.
- PreReq tuned.

* Tue Nov 11 2003 Anton V. Denisov <avd@altlinux.org> 0.99.10.2-alt0.1
- Updated to 0.99.10.2 (bugfix release).
- Removed auth-no-homedir.patch (no longer need).
- Updated our patches for new version.
- Add Packager tag.
- added %postun for user removal and commented it out.
- TODO is still todo.

* Mon Nov 10 2003 Anton V. Denisov <avd@altlinux.org> 0.99.10-alt0.1
- New version 0.99.10.
- Applied upstream bugfix patch.
- Added alt-conf-paths.patch
- Updated alt-mkcert.patch
- Updated %%description.
- Updated buildrequires.
- PAM config renamed: imap->%name
- SSL/TLS certs renamed.
- Additional flags for %%configure.
- Temporary build with --without-pop3d (should we?)
- Use default config instead of our.
- Mark %_initdir/%name as %%config(noreplace) (should we?).
- Init script updated.
- Corrected permissions for %_var/run/%name and %_var/run/%name/login.
- Other minor updates in spec file.
- TODO:
  + build and split modules (like postfix2 package).
  + other.

* Sun Nov 09 2003 Anton V. Denisov <avd@altlinux.org> 0.99.4-alt0.2
- Initial build for ALT Linux.
- Spec file cleaned up and improved (courier-imap.spec as example).
- Automatically added BuildRequires.
- %%confugure with additional keys.
- PAM configs added.
- Create user for imap-login process.
- added sample default config
- SSL/TLS certs generation during package install (need more working)
- TODO:
  + check FHS and ALT policy compliance
  + with/without logic of build (do we need shadow-auth support?)

* Sun Dec  1 2002 Seth Vidal <skvidal@phy.duke.edu>
- 0.99.4 and fix startup so it starts imap-master not vsftpd :)

* Tue Nov 26 2002 Seth Vidal <skvidal@phy.duke.edu>
- first build
